Struct rolling_stats::Stats [−][src]
Stats object calculates continuous min/max/mean/deviation for tracking of time varying statistics.
See: https://en.wikipedia.org/wiki/Algorithms_for_calculating_variance#Welford's_Online_algorithm for Details of the underlying algorithm.
Fields
min: TMinimum value
max: TMaximum value
mean: TMean of sample set
std_dev: TStandard deviation of sample
count: usizeNumber of values collected
Implementations
impl<T> Stats<T> where
T: Float + Zero + One + AddAssign + FromPrimitive + PartialEq + Debug, [src]
T: Float + Zero + One + AddAssign + FromPrimitive + PartialEq + Debug,
pub fn new() -> Stats<T>[src]
Create a new stats object
pub fn update(&mut self, value: T)[src]
Update the stats object
pub fn merge<S: Iterator<Item = Stats<T>>>(stats: S) -> Stats<T>[src]
Merge a set of stats objects for analysis This performs a weighted averaging across the provided stats object, the output object should not be updated further.